@@ -150,6 +150,9 @@ static guint64 mount_poller_time = 0;
 
 #ifdef HAVE_MNTENT_H
 #include <mntent.h>
+#ifdef HAVE_LIBMOUNT
+#include <libmount/libmount.h>
+#endif
 #elif defined (HAVE_SYS_MNTTAB_H)
 #include <sys/mnttab.h>
 #endif
@@ -323,25 +326,117 @@ guess_system_internal (const char *mountpoint,
 
 /* GUnixMounts (ie: mtab) implementations {{{1 */
 
+static GUnixMountEntry *
+create_unix_mount_entry (const char *device_path,
+                         const char *mount_path,
+                         const char *filesystem_type,
+                         gboolean    is_read_only)
+{
+  GUnixMountEntry *mount_entry = NULL;
+
+  mount_entry = g_new0 (GUnixMountEntry, 1);
+  mount_entry->device_path = g_strdup (device_path);
+  mount_entry->mount_path = g_strdup (mount_path);
+  mount_entry->filesystem_type = g_strdup (filesystem_type);
+  mount_entry->is_read_only = is_read_only;
+
+  mount_entry->is_system_internal =
+    guess_system_internal (mount_entry->mount_path,
+                           mount_entry->filesystem_type,
+                           mount_entry->device_path);
+  return mount_entry;
+}
+
+static GUnixMountPoint *
+create_unix_mount_point (const char *device_path,
+                         const char *mount_path,
+                         const char *filesystem_type,
+                         const char *options,
+                         gboolean    is_read_only,
+                         gboolean    is_user_mountable,
+                         gboolean    is_loopback)
+{
+  GUnixMountPoint *mount_point = NULL;
+
+  mount_point = g_new0 (GUnixMountPoint, 1);
+  mount_point->device_path = g_strdup (device_path);
+  mount_point->mount_path = g_strdup (mount_path);
+  mount_point->filesystem_type = g_strdup (filesystem_type);
+  mount_point->options = g_strdup (options);
+  mount_point->is_read_only = is_read_only;
+  mount_point->is_user_mountable = is_user_mountable;
+  mount_point->is_loopback = is_loopback;
+
+  return mount_point;
+}
+
 /* mntent.h (Linux, GNU, NSS) {{{2 */
 #ifdef HAVE_MNTENT_H
 
-static char *
-get_mtab_read_file (void)
+#ifdef HAVE_LIBMOUNT
+
+/* For documentation on /proc/self/mountinfo see
+ * http://www.kernel.org/doc/Documentation/filesystems/proc.txt
+ */
+#define PROC_MOUNTINFO_PATH "/proc/self/mountinfo"
+
+static GList *
+_g_get_unix_mounts (void)
 {
-#ifdef _PATH_MOUNTED
-# ifdef __linux__
-  return "/proc/mounts";
-# else
-  return _PATH_MOUNTED;
-# endif
-#else
-  return "/etc/mtab";
-#endif
+  struct libmnt_table *table = NULL;
+  struct libmnt_context *ctxt = NULL;
+  struct libmnt_iter* iter = NULL;
+  struct libmnt_fs *fs = NULL;
+  GUnixMountEntry *mount_entry = NULL;
+  GList *return_list = NULL;
+
+  ctxt = mnt_new_context ();
+  mnt_context_get_mtab (ctxt, &table);
+  if (!table)
+    goto out;
+
+  iter = mnt_new_iter (MNT_ITER_FORWARD);
+  while (mnt_table_next_fs (table, iter, &fs) == 0)
+    {
+      const char *device_path = NULL;
+      char *mount_options = NULL;
+      unsigned long mount_flags = 0;
+      gboolean is_read_only = FALSE;
+
+      if (!mnt_table_is_fs_mounted (table, fs))
+        continue;
+
+      device_path = mnt_fs_get_source (fs);
+      if (g_strcmp0 (device_path, "/dev/root") == 0)
+        device_path = _resolve_dev_root ();
+
+      mount_options = mnt_fs_strdup_options (fs);
+      if (mount_options)
+        {
+          mnt_optstr_get_flags (mount_options, &mount_flags, mnt_get_builtin_optmap (MNT_LINUX_MAP));
+          g_free (mount_options);
+        }
+      is_read_only = (mount_flags & MS_RDONLY) ? TRUE : FALSE;
+
+      mount_entry = create_unix_mount_entry (device_path,
+                                             mnt_fs_get_target (fs),
+                                             mnt_fs_get_fstype (fs),
+                                             is_read_only);
+
+      return_list = g_list_prepend (return_list, mount_entry);
+    }
+  mnt_free_iter (iter);
+
+ out:
+  mnt_free_context (ctxt);
+
+  return g_list_reverse (return_list);
 }
 
+#else
+
 static char *
-get_mtab_monitor_file (void)
+get_mtab_read_file (void)
 {
 #ifdef _PATH_MOUNTED
 # ifdef __linux__
@@ -389,6 +484,9 @@ _g_get_unix_mounts (void)
   while ((mntent = getmntent (file)) != NULL)
 #endif
     {
+      const char *device_path = NULL;
+      gboolean is_read_only = FALSE;
+
       /* ignore any mnt_fsname that is repeated and begins with a '/'
        *
        * We do this to avoid being fooled by --bind mounts, since
@@ -403,29 +501,26 @@ _g_get_unix_mounts (void)
 	  mntent->mnt_fsname[0] == '/' &&
 	  g_hash_table_lookup (mounts_hash, mntent->mnt_fsname))
         continue;
-      
-      mount_entry = g_new0 (GUnixMountEntry, 1);
-      mount_entry->mount_path = g_strdup (mntent->mnt_dir);
+
       if (g_strcmp0 (mntent->mnt_fsname, "/dev/root") == 0)
-        mount_entry->device_path = g_strdup (_resolve_dev_root ());
+        device_path = _resolve_dev_root ();
       else
-        mount_entry->device_path = g_strdup (mntent->mnt_fsname);
-      mount_entry->filesystem_type = g_strdup (mntent->mnt_type);
-      
+        device_path = mntent->mnt_fsname;
+
 #if defined (HAVE_HASMNTOPT)
       if (hasmntopt (mntent, MNTOPT_RO) != NULL)
-	mount_entry->is_read_only = TRUE;
+	is_read_only = TRUE;
 #endif
-      
-      mount_entry->is_system_internal =
-	guess_system_internal (mount_entry->mount_path,
-			       mount_entry->filesystem_type,
-			       mount_entry->device_path);
-      
+
+      mount_entry = create_unix_mount_entry (device_path,
+                                             mntent->mnt_dir,
+                                             mntent->mnt_type,
+                                             is_read_only);
+
       g_hash_table_insert (mounts_hash,
 			   mount_entry->device_path,
 			   mount_entry->device_path);
-      
+
       return_list = g_list_prepend (return_list, mount_entry);
     }
   g_hash_table_destroy (mounts_hash);
@@ -439,6 +534,41 @@ _g_get_unix_mounts (void)
   return g_list_reverse (return_list);
 }
 
+#endif /* HAVE_LIBMOUNT */
+
+static char *
+get_mtab_monitor_file (void)
+{
+  static char *mountinfo_path = NULL;
+#ifdef HAVE_LIBMOUNT
+  struct stat buf;
+#endif
+
+  if (mountinfo_path != NULL)
+    return mountinfo_path;
+
+#ifdef HAVE_LIBMOUNT
+  /* If using libmount we'll have the logic in place to read mountinfo */
+  if (stat (PROC_MOUNTINFO_PATH, &buf) == 0)
+    {
+      mountinfo_path = PROC_MOUNTINFO_PATH;
+      return mountinfo_path;
+    }
+#endif
+
+#ifdef _PATH_MOUNTED
+# ifdef __linux__
+  mountinfo_path = "/proc/mounts";
+# else
+  mountinfo_path = _PATH_MOUNTED;
+# endif
+#else
+  mountinfo_path = "/etc/mtab";
+#endif
+
+  return mountinfo_path;
+}
+
 /* mnttab.h {{{2 */
 #elif defined (HAVE_SYS_MNTTAB_H)
 
@@ -480,22 +610,18 @@ _g_get_unix_mounts (void)
   G_LOCK (getmntent);
   while (! getmntent (file, &mntent))
     {
-      mount_entry = g_new0 (GUnixMountEntry, 1);
-      
-      mount_entry->mount_path = g_strdup (mntent.mnt_mountp);
-      mount_entry->device_path = g_strdup (mntent.mnt_special);
-      mount_entry->filesystem_type = g_strdup (mntent.mnt_fstype);
-      
+      gboolean is_read_only = FALSE;
+
 #if defined (HAVE_HASMNTOPT)
       if (hasmntopt (&mntent, MNTOPT_RO) != NULL)
-	mount_entry->is_read_only = TRUE;
+	is_read_only = TRUE;
 #endif
 
-      mount_entry->is_system_internal =
-	guess_system_internal (mount_entry->mount_path,
-			       mount_entry->filesystem_type,
-			       mount_entry->device_path);
-      
+      mount_entry = create_unix_mount_entry (mntent.mnt_special,
+                                             mntent.mnt_mountp,
+                                             mntent.mnt_fstype,
+                                             is_read_only);
+
       return_list = g_list_prepend (return_list, mount_entry);
     }
   
@@ -550,25 +676,18 @@ _g_get_unix_mounts (void)
   return_list = NULL;
   while (vmount_number > 0)
     {
-      mount_entry = g_new0 (GUnixMountEntry, 1);
-      
-      mount_entry->device_path = g_strdup (vmt2dataptr (vmount_info, VMT_OBJECT));
-      mount_entry->mount_path = g_strdup (vmt2dataptr (vmount_info, VMT_STUB));
-      /* is_removable = (vmount_info->vmt_flags & MNT_REMOVABLE) ? 1 : 0; */
-      mount_entry->is_read_only = (vmount_info->vmt_flags & MNT_READONLY) ? 1 : 0;
+      gboolean is_read_only = FALSE;
 
       fs_info = getvfsbytype (vmount_info->vmt_gfstype);
-      
-      if (fs_info == NULL)
-	mount_entry->filesystem_type = g_strdup ("unknown");
-      else
-	mount_entry->filesystem_type = g_strdup (fs_info->vfsent_name);
 
-      mount_entry->is_system_internal =
-	guess_system_internal (mount_entry->mount_path,
-			       mount_entry->filesystem_type,
-			       mount_entry->device_path);
-      
+      /* is_removable = (vmount_info->vmt_flags & MNT_REMOVABLE) ? 1 : 0; */
+      is_read_only = (vmount_info->vmt_flags & MNT_READONLY) ? 1 : 0;
+
+      mount_entry = create_unix_mount_entry (vmt2dataptr (vmount_info, VMT_OBJECT),
+                                             vmt2dataptr (vmount_info, VMT_STUB),
+                                             fs_info == NULL ? "unknown" : fs_info->vfsent_name,
+                                             is_read_only);
+
       return_list = g_list_prepend (return_list, mount_entry);
       
       vmount_info = (struct vmount *)( (char*)vmount_info 
@@ -628,11 +747,7 @@ _g_get_unix_mounts (void)
   
   for (i = 0; i < num_mounts; i++)
     {
-      mount_entry = g_new0 (GUnixMountEntry, 1);
-      
-      mount_entry->mount_path = g_strdup (mntent[i].f_mntonname);
-      mount_entry->device_path = g_strdup (mntent[i].f_mntfromname);
-      mount_entry->filesystem_type = g_strdup (mntent[i].f_fstypename);
+      gboolean is_read_only = FALSE;
 
 #if defined(USE_STATVFS)
       if (mntent[i].f_flag & ST_RDONLY)
@@ -641,13 +756,13 @@ _g_get_unix_mounts (void)
 #else
       #error statfs juggling failed
 #endif
-        mount_entry->is_read_only = TRUE;
+        is_read_only = TRUE;
+
+      mount_entry = create_unix_mount_entry (mntent[i].f_mntfromname,
+                                             mntent[i].f_mntonname,
+                                             mntent[i].f_fstypename,
+                                             is_read_only);
 
-      mount_entry->is_system_internal =
-        guess_system_internal (mount_entry->mount_path,
-                               mount_entry->filesystem_type,
-                               mount_entry->device_path);
-      
       return_list = g_list_prepend (return_list, mount_entry);
     }
 
@@ -728,6 +843,9 @@ _g_get_unix_mounts (void)
 static char *
 get_fstab_file (void)
 {
+#ifdef HAVE_LIBMOUNT
+  return (char *) mnt_get_fstab_path ();
+#else
 #if defined(HAVE_SYS_MNTCTL_H) && defined(HAVE_SYS_VMOUNT_H) && defined(HAVE_SYS_VFS_H)
   /* AIX */
   return "/etc/filesystems";
@@ -738,10 +856,103 @@ get_fstab_file (void)
 #else
   return "/etc/fstab";
 #endif
+#endif
 }
 
 /* mntent.h (Linux, GNU, NSS) {{{2 */
 #ifdef HAVE_MNTENT_H
+
+#ifdef HAVE_LIBMOUNT
+
+static GList *
+_g_get_unix_mount_points (void)
+{
+  struct libmnt_table *table = NULL;
+  struct libmnt_context *ctxt = NULL;
+  struct libmnt_iter* iter = NULL;
+  struct libmnt_fs *fs = NULL;
+  GUnixMountPoint *mount_point = NULL;
+  GList *return_list = NULL;
+
+  ctxt = mnt_new_context ();
+  mnt_context_get_fstab (ctxt, &table);
+  if (!table)
+    goto out;
+
+  iter = mnt_new_iter (MNT_ITER_FORWARD);
+  while (mnt_table_next_fs (table, iter, &fs) == 0)
+    {
+      const char *device_path = NULL;
+      const char *mount_path = NULL;
+      const char *mount_fstype = NULL;
+      char *mount_options = NULL;
+      gboolean is_read_only = FALSE;
+      gboolean is_user_mountable = FALSE;
+      gboolean is_loopback = FALSE;
+
+      mount_path = mnt_fs_get_target (fs);
+      if ((strcmp (mount_path, "ignore") == 0) ||
+          (strcmp (mount_path, "swap") == 0) ||
+          (strcmp (mount_path, "none") == 0))
+        continue;
+
+      mount_fstype = mnt_fs_get_fstype (fs);
+      mount_options = mnt_fs_strdup_options (fs);
+      if (mount_options)
+        {
+          unsigned long mount_flags = 0;
+          unsigned long userspace_flags = 0;
+
+          mnt_optstr_get_flags (mount_options, &mount_flags, mnt_get_builtin_optmap (MNT_LINUX_MAP));
+          mnt_optstr_get_flags (mount_options, &userspace_flags, mnt_get_builtin_optmap (MNT_USERSPACE_MAP));
+
+          /* We ignore bind fstab entries, as we ignore bind mounts anyway */
+          if (mount_flags & MS_BIND)
+            {
+              g_free (mount_options);
+              continue;
+            }
+
+          is_read_only = (mount_flags & MS_RDONLY) != 0;
+          is_loopback = (userspace_flags & MNT_MS_LOOP) != 0;
+
+          if ((mount_fstype != NULL && g_strcmp0 ("supermount", mount_fstype) == 0) ||
+              ((userspace_flags & MNT_MS_USER) &&
+               (g_strstr_len (mount_options, -1, "user_xattr") == NULL)) ||
+              (g_strstr_len (mount_options, -1, "pamconsole") == NULL) ||
+              (userspace_flags & MNT_MS_USERS) ||
+              (userspace_flags & MNT_MS_OWNER))
+            {
+              is_user_mountable = TRUE;
+            }
+        }
+
+      device_path = mnt_fs_get_source (fs);
+      if (g_strcmp0 (device_path, "/dev/root") == 0)
+        device_path = _resolve_dev_root ();
+
+      mount_point = create_unix_mount_point (device_path,
+                                             mount_path,
+                                             mount_fstype,
+                                             mount_options,
+                                             is_read_only,
+                                             is_user_mountable,
+                                             is_loopback);
+      if (mount_options)
+        g_free (mount_options);
+
+      return_list = g_list_prepend (return_list, mount_point);
+    }
+  mnt_free_iter (iter);
+
+ out:
+  mnt_free_context (ctxt);
+
+  return g_list_reverse (return_list);
+}
+
+#else
+
 static GList *
 _g_get_unix_mount_points (void)
 {
@@ -752,7 +963,7 @@ _g_get_unix_mount_points (void)
   struct mntent *mntent;
   FILE *file;
   char *read_file;
-  GUnixMountPoint *mount_entry;
+  GUnixMountPoint *mount_point;
   GList *return_list;
   
   read_file = get_fstab_file ();
@@ -770,6 +981,11 @@ _g_get_unix_mount_points (void)
   while ((mntent = getmntent (file)) != NULL)
 #endif
     {
+      const char *device_path = NULL;
+      gboolean is_read_only = FALSE;
+      gboolean is_user_mountable = FALSE;
+      gboolean is_loopback = FALSE;
+
       if ((strcmp (mntent->mnt_dir, "ignore") == 0) ||
           (strcmp (mntent->mnt_dir, "swap") == 0) ||
           (strcmp (mntent->mnt_dir, "none") == 0))
@@ -781,24 +997,20 @@ _g_get_unix_mount_points (void)
         continue;
 #endif
 
-      mount_entry = g_new0 (GUnixMountPoint, 1);
-      mount_entry->mount_path = g_strdup (mntent->mnt_dir);
       if (strcmp (mntent->mnt_fsname, "/dev/root") == 0)
-        mount_entry->device_path = g_strdup (_resolve_dev_root ());
+        device_path = _resolve_dev_root ();
       else
-        mount_entry->device_path = g_strdup (mntent->mnt_fsname);
-      mount_entry->filesystem_type = g_strdup (mntent->mnt_type);
-      mount_entry->options = g_strdup (mntent->mnt_opts);
-      
+        device_path = mntent->mnt_fsname;
+
 #ifdef HAVE_HASMNTOPT
       if (hasmntopt (mntent, MNTOPT_RO) != NULL)
-	mount_entry->is_read_only = TRUE;
-      
+	is_read_only = TRUE;
+
       if (hasmntopt (mntent, "loop") != NULL)
-	mount_entry->is_loopback = TRUE;
-      
+	is_loopback = TRUE;
+
 #endif
-      
+
       if ((mntent->mnt_type != NULL && strcmp ("supermount", mntent->mnt_type) == 0)
 #ifdef HAVE_HASMNTOPT
 	  || (hasmntopt (mntent, "user") != NULL
@@ -808,9 +1020,17 @@ _g_get_unix_mount_points (void)
 	  || hasmntopt (mntent, "owner") != NULL
 #endif
 	  )
-	mount_entry->is_user_mountable = TRUE;
-      
-      return_list = g_list_prepend (return_list, mount_entry);
+	is_user_mountable = TRUE;
+
+      mount_point = create_unix_mount_point (device_path,
+                                             mntent->mnt_dir,
+                                             mntent->mnt_type,
+                                             mntent->mnt_opts,
+                                             is_read_only,
+                                             is_user_mountable,
+                                             is_loopback);
+
+      return_list = g_list_prepend (return_list, mount_point);
     }
   
   endmntent (file);
@@ -822,6 +1042,8 @@ _g_get_unix_mount_points (void)
   return g_list_reverse (return_list);
 }
 
+#endif /* HAVE_LIBMOUNT */
+
 /* mnttab.h {{{2 */
 #elif defined (HAVE_SYS_MNTTAB_H)
 
@@ -831,7 +1053,7 @@ _g_get_unix_mount_points (void)
   struct mnttab mntent;
   FILE *file;
   char *read_file;
-  GUnixMountPoint *mount_entry;
+  GUnixMountPoint *mount_point;
   GList *return_list;
   
   read_file = get_fstab_file ();
@@ -845,26 +1067,23 @@ _g_get_unix_mount_points (void)
   G_LOCK (getmntent);
   while (! getmntent (file, &mntent))
     {
+      gboolean is_read_only = FALSE;
+      gboolean is_user_mountable = FALSE;
+      gboolean is_loopback = FALSE;
+
       if ((strcmp (mntent.mnt_mountp, "ignore") == 0) ||
           (strcmp (mntent.mnt_mountp, "swap") == 0) ||
           (strcmp (mntent.mnt_mountp, "none") == 0))
 	continue;
-      
-      mount_entry = g_new0 (GUnixMountPoint, 1);
-      
-      mount_entry->mount_path = g_strdup (mntent.mnt_mountp);
-      mount_entry->device_path = g_strdup (mntent.mnt_special);
-      mount_entry->filesystem_type = g_strdup (mntent.mnt_fstype);
-      mount_entry->options = g_strdup (mntent.mnt_mntopts);
-      
+
 #ifdef HAVE_HASMNTOPT
       if (hasmntopt (&mntent, MNTOPT_RO) != NULL)
-	mount_entry->is_read_only = TRUE;
-      
+	is_read_only = TRUE;
+
       if (hasmntopt (&mntent, "lofs") != NULL)
-	mount_entry->is_loopback = TRUE;
+	is_loopback = TRUE;
 #endif
-      
+
       if ((mntent.mnt_fstype != NULL)
 #ifdef HAVE_HASMNTOPT
 	  || (hasmntopt (&mntent, "user") != NULL
@@ -874,9 +1093,17 @@ _g_get_unix_mount_points (void)
 	  || hasmntopt (&mntent, "owner") != NULL
 #endif
 	  )
-	mount_entry->is_user_mountable = TRUE;
-      
-      return_list = g_list_prepend (return_list, mount_entry);
+	is_user_mountable = TRUE;
+
+      mount_point = create_unix_mount_point (mntent.mnt_special,
+                                             mntent.mnt_mountp,
+                                             mntent.mnt_fstype,
+                                             mntent.mnt_mntopts,
+                                             is_read_only,
+                                             is_user_mountable,
+                                             is_loopback);
+
+      return_list = g_list_prepend (return_list, mount_point);
     }
   
   endmntent (file);
@@ -1001,7 +1228,7 @@ _g_get_unix_mount_points (void)
   struct mntent *mntent;
   FILE *file;
   char *read_file;
-  GUnixMountPoint *mount_entry;
+  GUnixMountPoint *mount_point;
   AixMountTableEntry mntent;
   GList *return_list;
   
@@ -1017,16 +1244,15 @@ _g_get_unix_mount_points (void)
     {
       if (strcmp ("cdrfs", mntent.mnt_fstype) == 0)
 	{
-	  mount_entry = g_new0 (GUnixMountPoint, 1);
-	  
-	  mount_entry->mount_path = g_strdup (mntent.mnt_mount);
-	  mount_entry->device_path = g_strdup (mntent.mnt_special);
-	  mount_entry->filesystem_type = g_strdup (mntent.mnt_fstype);
-	  mount_entry->options = g_strdup (mntent.mnt_options);
-	  mount_entry->is_read_only = TRUE;
-	  mount_entry->is_user_mountable = TRUE;
-	  
-	  return_list = g_list_prepend (return_list, mount_entry);
+          mount_point = create_unix_mount_point (mntent.mnt_special,
+                                                 mntent.mnt_mount,
+                                                 mntent.mnt_fstype,
+                                                 mntent.mnt_options,
+                                                 TRUE,
+                                                 TRUE,
+                                                 FALSE);
+
+	  return_list = g_list_prepend (return_list, mount_point);
 	}
     }
 	
@@ -1041,7 +1267,7 @@ static GList *
 _g_get_unix_mount_points (void)
 {
   struct fstab *fstab = NULL;
-  GUnixMountPoint *mount_entry;
+  GUnixMountPoint *mount_point;
   GList *return_list;
 #ifdef HAVE_SYS_SYSCTL_H
   int usermnt = 0;
@@ -1078,18 +1304,14 @@ _g_get_unix_mount_points (void)
   
   while ((fstab = getfsent ()) != NULL)
     {
+      gboolean is_read_only = FALSE;
+      gboolean is_user_mountable = FALSE;
+
       if (strcmp (fstab->fs_vfstype, "swap") == 0)
 	continue;
-      
-      mount_entry = g_new0 (GUnixMountPoint, 1);
-      
-      mount_entry->mount_path = g_strdup (fstab->fs_file);
-      mount_entry->device_path = g_strdup (fstab->fs_spec);
-      mount_entry->filesystem_type = g_strdup (fstab->fs_vfstype);
-      mount_entry->options = g_strdup (fstab->fs_mntops);
-      
+
       if (strcmp (fstab->fs_type, "ro") == 0)
-	mount_entry->is_read_only = TRUE;
+	is_read_only = TRUE;
 
 #ifdef HAVE_SYS_SYSCTL_H
       if (usermnt != 0)
@@ -1098,12 +1320,20 @@ _g_get_unix_mount_points (void)
 	  if (stat (fstab->fs_file, &sb) == 0)
 	    {
 	      if (uid == 0 || sb.st_uid == uid)
-		mount_entry->is_user_mountable = TRUE;
+		is_user_mountable = TRUE;
 	    }
 	}
 #endif
 
-      return_list = g_list_prepend (return_list, mount_entry);
+      mount_point = create_unix_mount_point (fstab->fs_spec,
+                                             fstab->fs_file,
+                                             fstab->fs_vfstype,
+                                             fstab->fs_mntops,
+                                             is_read_only,
+                                             is_user_mountable,
+                                             FALSE);
+
+      return_list = g_list_prepend (return_list, mount_point);
     }
   
   endfsent ();
